@@ -6,13 +6,14 @@
 #' 
 #' Transpose.
 #' 
-#' For advanced users only.
+#' For advanced users only. See pbdDMAT for high-level functions.
 #' 
 #' @param a
 #' Matrix.
 #' @param desca,descc
 #' ScaLAPACK descriptor array.
 #' 
+#' @useDynLib pbdBASE R_PDTRAN
 #' @export
 base.rpdtran <- function(a, desca, descc)
 {
@@ -29,7 +30,7 @@ base.rpdtran <- function(a, desca, descc)
                 a, as.integer(desca),
                 as.integer(cldim), as.integer(descc))
   
-  return(ret)
+  ret
 }
 
 # ------------------------------------------------
@@ -40,7 +41,7 @@ base.rpdtran <- function(a, desca, descc)
 #' 
 #' Matrix-Matrix Multiply.
 #' 
-#' For advanced users only.
+#' For advanced users only. See pbdDMAT for high-level functions.
 #' 
 #' @param transx,transy
 #' 'T' or 'N' for transpose or not.
@@ -49,6 +50,7 @@ base.rpdtran <- function(a, desca, descc)
 #' @param descx,descy,descc
 #' ScaLAPACK descriptor array.
 #' 
+#' @useDynLib pbdBASE R_PDGEMM
 #' @export
 base.rpdgemm <- function(transx, transy, x, descx, y, descy, descc)
 {
