@@ -4,7 +4,12 @@
 
 // Copyright 2013, Schmidt and Chen
 
+
+#include "pblas.h"
+
+// R.h and Rinternals.h needs to be included after Rconfig.h
 #include "pbdBASE.h"
+#include <RNACI.h>
 
 
 // Transpose
@@ -42,14 +47,22 @@ SEXP R_PDGEMM(SEXP TRANSA, SEXP TRANSB, SEXP M, SEXP N, SEXP K,
   newRmat(C, INT(CLDIM, 0), INT(CLDIM, 1), "dbl");
   
   
+#ifdef FC_LEN_T
+  pdgemm_(STR(TRANSA, 0), STR(TRANSB, 0),
+      INTP(M), INTP(N), INTP(K), &alpha, 
+      DBLP(A), &IJ, &IJ, INTP(DESCA),
+      DBLP(B), &IJ, &IJ, INTP(DESCB), &beta,
+      DBLP(C), &IJ, &IJ, INTP(DESCC),
+      (FC_LEN_T) strlen(STR(TRANSA, 0)), (FC_LEN_T) strlen(STR(TRANSB, 0)));
+#else
   pdgemm_(STR(TRANSA, 0), STR(TRANSB, 0),
       INTP(M), INTP(N), INTP(K), &alpha, 
       DBLP(A), &IJ, &IJ, INTP(DESCA),
       DBLP(B), &IJ, &IJ, INTP(DESCB), &beta,
       DBLP(C), &IJ, &IJ, INTP(DESCC));
+#endif
   
   
   R_END;
   return C;
 }
-
